California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 010 - EXPANDS LOCAL GOVERNMENTS? AUTHORITY TO ENACT RENT CONTROL ON RESIDENTIAL PROPERTY. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412518 | FUND FOR POLICY REFORM, SPONSORED BY FUND FOR POLICY REFORM TRUST, YES ON 10 (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1379198 | PHARMACEUTICAL RESEARCH AND MANUFACTURERS OF AMERICA CALIFORNIA INITIATIVE FUND - NO ON PROPOSITION 10 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1401516 | NO ON PROP 10; CALIFORNIANS FOR RESPONSIBLE HOUSING, A COALTION OF VETERANS, SENIORS, AFFORDABLE HOUSING PROVIDERS, SOCIAL JUSTICE GROUPS, TAXPAYER ASSOCIATIONS, AND LABOR; SPONSORED BY THE CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1406422 | NO ON PROP 10 - A FLAWED INITIATIVE THAT WILL MAKE THE HOUSING CRISIS WORSE A COALITION OF HOUSING ADVOCATES, RENTERS, LARGE AND SMALL BUSINESSES, TAXPAYER GROUPS, AND VETERANS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1406018 | CALIFORNIANS FOR AFFORDABLE HOUSING, NO ON PROPOSITION 10, SPONSORED BY THE CALIFORNIA RENTAL HOUSING ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1399958 | YES ON 10 - A COALITION OF TEACHERS, NURSES, SENIORS AND RENTERS FOR AFFORDABLE HOUSING, SPONSORED BY AIDS HEALTHCARE FOUNDATION AND ACCE ACTION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1406786 | CALIFORNIA RENTAL HOUSING ASSOCIATION, NO ON PROP 10 (NONPROFIT 501(C)(6)) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1409098 | MAKE HOUSING AFFORDABLE - YES ON PROP. 10, A COALITION OF COMMUNITY GROUPS, RENTERS, UNIONS, SMALL LANDLORDS AND HOMEOWNERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1411207 | MILLION VOTER PROJECT ACTION FUND, NO ON 5 YES ON 10, SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412097 | OPEN SOCIETY POLICY CENTER (NON-PROFIT 501(C)(4) - YES ON 10) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405723 | ISSUES PAC OF APARTMENT ASSOCIATION OF GREATER LOS ANGELES - NO ON 10 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412754 | EAST BAY HOUSING ORGANIZATIONS (NON PROFIT 501C3) - YES ON PROPS 1, 2 & 10 & NO ON PROP 5 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1412922 | SB HOUSING PROVIDERS AGAINST PROPOSITION 10, SPONSORED BY SANTA BARBARA RENTAL PROPERTY ASSN ISSUES PAC | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1283587 | MULTI-COUNTY PROPERTY RIGHTS PAC, SPONSORING NO ON PROP 10, SPONSORED BY APARTMENT ASSOCIATION OF ORANGE COUNTY | OPPOSE